@@ -28,6 +28,10 @@ class Configuration(CloudFormationLintRule):
         'Type',
     ]
 
+    required_keys = [
+        'Type'
+    ]
+
     def match(self, cfn):
         """Check CloudFormation Parameters"""
 
@@ -41,5 +45,12 @@ class Configuration(CloudFormationLintRule):
                         ['Parameters', paramname, propname],
                         message.format(paramname, propname)
                     ))
+            for reqname in self.required_keys:
+                if reqname not in paramvalue.keys():
+                    message = 'Parameter {0} is missing required property {1}'
+                    matches.append(RuleMatch(
+                        ['Parameters', paramname],
+                        message.format(paramname, reqname)
+                    ))
 
         return matches
