@@ -1,22 +1,11 @@
 """
-  Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-
-  Permission is hereby granted, free of charge, to any person obtaining a copy of this
-  software and associated documentation files (the "Software"), to deal in the Software
-  without restriction, including without limitation the rights to use, copy, modify,
-  merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
-  permit persons to whom the Software is furnished to do so.
-
-  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
-  INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
-  PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-  HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
-  OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
-  SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+SPDX-License-Identifier: MIT-0
 """
 from cfnlint.rules import CloudFormationLintRule
 from cfnlint.rules import RuleMatch
 import cfnlint.helpers
+from cfnlint.data import AdditionalSpecs
 
 
 class OnlyOne(CloudFormationLintRule):
@@ -32,7 +21,7 @@ class OnlyOne(CloudFormationLintRule):
     def __init__(self):
         """Init"""
         super(OnlyOne, self).__init__()
-        onlyonespec = cfnlint.helpers.load_resources('data/AdditionalSpecs/OnlyOne.json')
+        onlyonespec = cfnlint.helpers.load_resource(AdditionalSpecs, 'OnlyOne.json')
         self.resource_types_specs = onlyonespec['ResourceTypes']
         self.property_types_specs = onlyonespec['PropertyTypes']
         for resource_type_spec in self.resource_types_specs:
@@ -56,14 +45,17 @@ class OnlyOne(CloudFormationLintRule):
                         message = 'Only one of [{0}] should be specified for {1}'
                         matches.append(RuleMatch(
                             path,
-                            message.format(', '.join(map(str, onlyoneprop)), '/'.join(map(str, path)))
+                            message.format(', '.join(map(str, onlyoneprop)),
+                                           '/'.join(map(str, path)))
                         ))
                     else:
-                        scenario_text = ' and '.join(['when condition "%s" is %s' % (k, v) for (k, v) in property_set['Scenario'].items()])
+                        scenario_text = ' and '.join(['when condition "%s" is %s' % (
+                            k, v) for (k, v) in property_set['Scenario'].items()])
                         message = 'Only one of [{0}] should be specified {1} at {2}'
                         matches.append(RuleMatch(
                             path,
-                            message.format(', '.join(map(str, onlyoneprop)), scenario_text, '/'.join(map(str, path)))
+                            message.format(', '.join(map(str, onlyoneprop)),
+                                           scenario_text, '/'.join(map(str, path)))
                         ))
 
         return matches
